@@ -96,10 +96,13 @@ impl Client {
             }
         };
         if should_req_well_known {
-            if let Ok(z) = ureq::get(&self.host.clone()).call() {
+            if let Ok(z) = ureq::get(&format!("{}/.well-known/matrix/client", self.host.clone())).call() {
+                //panic!("{}", z.into_string().unwrap());
+                
                 let resp: Value = z.into_json().unwrap();
                 let base_url: String = resp["m.homeserver"]["base_url"].as_str().unwrap().to_string();
                 self.host = base_url.trim_end_matches("/").to_string();
+                
                 //self.me = UserId::try_from(format!("@{}:{}", self.me.localpart(), self.host.clone().split_once("://").unwrap().1).as_str()).unwrap();
             }
         }
